import { ErpTableOptions } from '@/types/type';

import { HeaderField } from '../type';

const getType = (type: any) => {
  const data = {
    type: 'input',
    value: '',
  } as any;

  switch (type) {
    case 'customNumber':
      data.type = 'number';
      data.filterProp = ['customDateStart', 'customDateEnd'];
      data.value = [];
      break;
    case 'customDate':
      data.type = 'time';
      data.value = [];
      data.filterProp = ['customDateStart', 'customDateEnd'];
      break;

    default:
      data.type = 'input';
      data.value = '';
  }
  return data;
};

//设置筛选表头信息，包含特殊筛选类型
const getCustomFieldData = (customData: HeaderField[], columOptions: ErpTableOptions[], isRender: boolean) => {
  let filterOptions: ErpTableOptions[] = [];
  customData.forEach((item) => {
    if (item.type) {
      let { type, value, filterProp } = getType(item.type as any);
      const tableOpt: ErpTableOptions = {
        label: item.name,
        prop: item.fieldName,
        minWidth: item.width,
        isHidden: item.isHide,
        fixed: item.isFixed ? 'left' : undefined,
        align: item.align,
        type: type,
        value: value,
        filterProp: filterProp,
      };
      if (item.isHide === false) {
        filterOptions.push(tableOpt);
      }
    } else {
      columOptions.forEach((v) => {
        if ((v.prop === item.fieldName || v.propDesc === item.fieldName) && item.isHide === false) {
          v.minWidth = item.width;
          v.isHidden = item.isHide;
          v.fixed = item.isFixed ? 'left' : undefined;
          v.align = item.align;
          filterOptions.push(v);
        }
      });
    }
  });

  // 这里不放在上面循环是因为要把特殊的字段放在最后
  columOptions.forEach((v) => {
    if (v.isSpecialFilter === true) {
      filterOptions.push(v);
    }
  });
  // 添加操作表头进去，这个不受自定义控制
  let index = columOptions.findIndex((v) => v.label === '操作');
  if (index > -1) {
    filterOptions.push(columOptions[index]);
  }
  return filterOptions;
};
export default {
  getCustomFieldData,
};
